module.exports = defineTest({
	description: 'keeps conditional expressions if their test value is reassigned'
});
